Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type File ¶
type File struct {
// Version represents the version of nrdeco used to generate this file.
Version string
PackageName string
OriginalPackageName string
Imports map[string]Package
Interfaces []Interface
// DifferInDest indicates if the file to be generated in a different destination than the original file.
DifferInDest bool
}
File represents a Go source file
func (*File) InterfaceNameWithPackage ¶
InterfaceNameWithPackage returns the interface name with the package identifier if the file is generated in a different destination than the original file.
func (*File) StringOfImports ¶
StringOfImports returns a string representation of the imports in the file, sorted by package path
type Params ¶
type Params []Value
Params represents the method parameters
func (*Params) BeGenerated ¶
BeGenerated checks if the Params slice contains follow parameters that should be generated.
- context.Context
type Value ¶
type Value struct {
Package *Package
Type string
Key string
Element *Value
Params Params
Returns Returns
}
Value represents a parameter or return value.
func (*Value) IsContext ¶
IsContext return true if the value is a context.Context type, otherwise false.
func (*Value) StringOfType ¶
StringOfType returns the string representation of the value's type
Click to show internal directories.
Click to hide internal directories.